==> nsm-console-0.3.tar.gz: nsm-console/lib/encodelib.rb <==
## Class encapsulating all the encode/decode methods
class Encoder
  def Encoder.get_encode_list
    ["base64","md5","sha256","urlescape","binary_MSB","binary_LSB","hex_MSB","hex_LSB"]
  end
  def Encoder.get_decode_list
    ["base64","urlescape","binary_MSB","binary_LSB","hex"]
  end

  ## Encoder methods
  def Encoder.encode_base64(str)
    require 'base64'
    return Base64.encode64(str)
  end

  def Encoder.encode_md5(str)
    require 'digest/md5'
    return Digest::MD5.hexdigest(str)
  end

  def Encoder.encode_sha256(str)
    require 'digest/sha2'
    return Digest::SHA256.hexdigest(str)
  end

  def Encoder.encode_urlescape(str)
    require 'CGI'
    return CGI.escape(str)
  end
  
  def Encoder.encode_binary_MSB(str)
    return str.unpack('B*').to_s
  end
  def Encoder.encode_binary_LSB(str)
    return str.unpack('b*').to_s
  end
  
  def Encoder.encode_hex_LSB(str)
    return str.unpack('h*').to_s
  end
  def Encoder.encode_hex_MSB(str)
    return str.unpack('H*').to_s
  end
  
  ## Decoder methods
  def Encoder.decode_base64(str)
    require 'base64'
    return Base64.decode64(str)
  end

  def Encoder.decode_urlescape(str)
    require 'CGI'
    return CGI.unescape(str)
  end
  
  def Encoder.decode_binary_MSB(str)
    return str.to_a.pack('B*')
  end
  def Encoder.decode_binary_LSB(str)
    return str.to_a.pack('b*')
  end
  
  def Encoder.decode_hex(str)
    out = ""
    str.scan(/../).each { |h| out += h.hex.chr; }
    return out
  end
  
end

## Add methods to tab completion
enclist = Encoder.get_encode_list()
declist = Encoder.get_decode_list()
list = enclist.concat(declist)
list.uniq!
list.each { |l|
  $tabstrings.push(l.to_s)
}

==> nsm-console-0.6.tar.gz: nsm-console/lib/encodelib.rb <==
## Class encapsulating all the encode/decode methods
class Encoder
  def Encoder.get_encode_list
    ["base64","md5","sha256","urlescape","binary_MSB","binary_LSB","hex_MSB","hex_LSB","uuencode","rot13"]
  end
  def Encoder.get_decode_list
    ["base64","urlescape","binary_MSB","binary_LSB","hex","char","uudecode","octal","rot13"]
  end

  ## Encoder methods
  def Encoder.encode_base64(str)
    require 'base64'
    return Base64.encode64(str)
  end

  def Encoder.encode_md5(str)
    require 'digest/md5'
    return Digest::MD5.hexdigest(str)
  end

  def Encoder.encode_sha256(str)
    require 'digest/sha2'
    return Digest::SHA256.hexdigest(str)
  end

  def Encoder.encode_urlescape(str)
    require 'cgi'
    return CGI.escape(str)
  end
  
  def Encoder.encode_binary_MSB(str)
    return str.unpack('B*').to_s
  end
  def Encoder.encode_binary_LSB(str)
    return str.unpack('b*').to_s
  end
  
  def Encoder.encode_hex_LSB(str)
    return str.unpack('h*').to_s
  end
  def Encoder.encode_hex_MSB(str)
    return str.unpack('H*').to_s
  end
  
  def Encoder.encode_uuencode(str)
    return [str].pack('u*').to_s
  end
  
  def Encoder.encode_rot13(str)
    return str.downcase.rot13
  end
  
  ## Decoder methods
  def Encoder.decode_base64(str)
    require 'base64'
    return Base64.decode64(str)
  end

  def Encoder.decode_urlescape(str)
    require 'cgi'
    return CGI.unescape(str)
  end
  
  def Encoder.decode_binary_MSB(str)
    return str.to_a.pack('B*')
  end
  def Encoder.decode_binary_LSB(str)
    return str.to_a.pack('b*')
  end
  
  def Encoder.decode_hex(str)
    out = ""
    str.scan(/../).each { |h| out += h.hex.chr; }
    return out
  end
  
  def Encoder.decode_char(str)
    out = ""
    str.split(/ /).each { |c|
      out = out + c.to_i.chr.to_s
    }
    return out
  end
  
  def Encoder.decode_uudecode(str)
    return str.unpack('u*').to_s
  end
  
  def Encoder.decode_octal(str)
    out = ""
    str.scan(/.../).each { |o|
      out = out + o.oct.chr
    }
    return out
  end
  
  def Encoder.decode_rot13(str)
    return str.downcase.rot13
  end
  
end

## Add methods to tab completion
enclist = Encoder.get_encode_list()
declist = Encoder.get_decode_list()
list = enclist.concat(declist)
list.uniq!
list.each { |l|
  $tabstrings.push(l.to_s)
}
